# -*- coding:utf-8 -*-
import os, sys
from .. import isDreamOS, PluginLanguageDomain, medialist
from .EPGImport import bigStorage
from ..config import E2m3u2bConfig
from ..e2m3u2bouquet import EPGIMPORTPATH as settingspath
if isDreamOS:
	from . import epgdb
else:
	from . import epgdat

logger = E2m3u2bConfig.logger
tmppath = bigStorage(9000000, *medialist)


class EPGClass(object):

	services = []

	def __init__(self, epgfile):
		if isDreamOS:
			self.epg = epgdb.epgdb_class(PluginLanguageDomain, 99, epgfile)
		else:
			epgfile = os.path.join(tmppath, 'epg_new.dat')
			self.epg = epgdat.epgdat_class(tmppath, settingspath, epgfile)

		logger.debug("EPG database located at %s" % epgfile)

	def importEvents(self, services, events):
		'''This method is called repeatedly for each bit of data'''
		for event in events:
			event = list(event)
			if not isDreamOS:
				event[3] += event[4]
				event = event[:4]
			self.epg.add_event(event)

		self.services = services
		self.commitService()

	def commitService(self):
		if self.services is not None:
			self.epg.preprocess_events_channel(self.services)

	def epg_done(self):
		try:
			self.commitService()
		except Exception as e:
			logger.error("[epgdat_importer] failure in epg_done: %s" % e)
		finally:
			self.epg.final_process()
			self.epg = None

	def __del__(self):
		'''Destructor - finalize the file when done'''
		if self.epg is not None:
			self.epg_done()
